@@ -29,6 +29,7 @@ PERL=${PERL:-perl}
 PERL=`echo $PERL|sed -e's,^",,; s,"$,,'`
 v510=`$PERL -e'print (($] < 5.010)?0:1)'`
 v518=`$PERL -e'print (($] < 5.018)?0:1)'`
+#v522=`$PERL -e'print (($] < 5.022)?0:1)'`
 PERLV=v5.`$PERL -e'print substr($],3,2)'`
 XTESTC="t/CORE/$PERLV/C-COMPILED/xtestc"
 
@@ -543,7 +544,7 @@ result[138]='abc'
 tests[140]='my %a;print "ok" if !%a;'
 #tests[141]='print "ok" if "1" > 0'
 tests[141]='@x=(0..1);print "ok" if $#x == "1"'
-tests[142]='$_ = "abc\x{1234}";chop;print "ok" if $_ eq "abc"'
+tests[142]='$_ = "abc\x{1234}";chop;print $_ eq "abc" ? "ok" : $_;'
 tests[143]='BEGIN {
   package Net::IDN::Encode;
   our $DOT = qr/[\.]/; #works with my!
@@ -754,6 +755,7 @@ tests[185]='my $a=pack("U",0xFF);use bytes;print "not " unless $a eq "\xc3\xbf"
 tests[186]='eval q/require B/; my $sub = do { package one; \&{"one"}; }; delete $one::{one}; my $x = "boom"; print "ok\n";'
 # duplicate of 182
 tests[187]='my $glob = \*Phoo::glob; undef %Phoo::; print ( ( "$$glob" eq "*__ANON__::glob" ) ? "ok\n" : "fail with $$glob\n" );'
+# See also GH 252 + 360
 tests[188]='package aiieee;sub zlopp {(shift =~ m?zlopp?) ? 1 : 0;} sub reset_zlopp {reset;}
 package main; print aiieee::zlopp(""), aiieee::zlopp("zlopp"), aiieee::zlopp(""), aiieee::zlopp("zlopp");
 aiieee::reset_zlopp(); print aiieee::zlopp("zlopp")'
@@ -783,6 +785,10 @@ print ($s =~ /ccdave with long name/ ? q(ok) : $s);'
 tests[1941]='$0 = q{ccdave}; #print "pid: $$\n";
 $s=`ps auxw | grep "$$" | grep "ccdave"|grep -v grep`;
 print q(ok) if $s =~ /ccdave/'
+# VmRSS memory usage
+tests[1942]='$s=<DATA>;print `ps -p $$ -O rss,vsz,pmem`;
+__DATA__
+a'
 # duplicate of 152
 tests[195]='use PerlIO;  eval { require PerlIO::scalar }; find PerlIO::Layer "scalar"; print q(ok)'
 tests[196]='package Foo;
@@ -827,7 +833,7 @@ tests[2011]='sub can {require Config; import Config;return $Config{d_flock}}
 use IO::File;
 can();
 print "ok\n";'
-tests[203]='#TODO perlio layers
+tests[203]='#TODO <5.22 perlio layers
 use open(IN => ":crlf", OUT => ":encoding(cp1252)");
 open F, "<", "/dev/null";
 my %l = map {$_=>1} PerlIO::get_layers(F, input  => 1);
@@ -1011,7 +1017,18 @@ sub f :lvalue;print "ok" if exists &f'
 tests[2512]='sub f ();print "ok" if exists &f'
 tests[2513]='sub f ($);print "ok" if exists &f'
 tests[2514]='sub f;print "ok" if exists &f'
+# see also 188
 tests[252]='package bar; sub search { shift =~ m?bar? ? 1 : 0 } sub reset_zlopp { reset } package foo; sub ZZIP { shift =~ m?ZZIP? ? 1 : 0 } package main; foo::ZZIP("ZZIP"); bar::reset_zlopp(); !foo::ZZIP("ZZIP") and print "ok"'
+# same as 188
+tests[2520]='package aiieee;sub zlopp {(shift =~ m?zlopp?) ? 1 : 0;} sub reset_zlopp {reset;}
+package main; print aiieee::zlopp(""), aiieee::zlopp("zlopp"), aiieee::zlopp(""), aiieee::zlopp("zlopp");
+aiieee::reset_zlopp(); print "ok" if aiieee::zlopp("zlopp") eq "01001"'
+tests[2521]='package aiieee;sub zlopp { (shift =~ m?zlopp?) ? 1 : 0 } sub reset_zlopp { reset }
+package main;
+aiieee::zlopp("");
+aiieee::zlopp("zlopp");
+aiieee::reset_zlopp();
+print "ok\n" if aiieee::zlopp("zlopp");'
 tests[253]='use Unicode::UCD q/prop_invmap/; my @list = prop_invmap("Uppercase_Mapping"); print "ok"'
 tests[2530]='INIT{require "t/test.pl"}plan(tests=>2);is("\x{2665}", v9829);is(v9829,"\x{2665}");'
 result[2530]='1..2
@@ -1323,6 +1340,15 @@ $foo->method;'
 tests[350]='#TODO 5.18-5.22 dbg
 package Foo::Moose; use Moose; has bar => (is => "rw", isa => "Int");
 package main; my $moose = Foo::Moose->new; print "ok" if 32 == $moose->bar(32);'
+tests[351]='{ BEGIN { *Mover:: = *Mover2::; *Mover2:: = *foo;} 
+package Mover;
+@ISA = "door"; sub door::dohtem { "dohtem" } print "ok\n";}'
+tests[352]='package Foo;my $rand = 0;INIT { *reader = sub () { $rand };}
+print qq/ok\n/;'
+tests[354]='BEGIN { push @INC, "t"; }
+use Ccode354i ();
+my $token = { expansion => "abcd", };
+print Ccode354i::check($token);'
 tests[368]='use EV; print q(ok)'
 tests[369]='
 use EV;
@@ -1378,6 +1404,13 @@ tests[2193]='{local $^W = 1; my $warn = "";
 local $SIG{__WARN__} = sub { $warn .= join("",@_) };
 eval q(sub badproto4 (@ $b ar) { 1; });
 print $warn =~ /Prototype after .@. for main::badproto4/ ? "ok" : $warn;}'
+# GH 330
+tests[3300]='#WONTFIX
+*STDOUT; sub IO::Handle::self { $_[0] };
+(*STDOUT->self . "") =~ m/^GLOB/ and print "ok\n"'
+tests[3301]='#WORKAROUND 3300
+IO::Handle->new if $ENV{none}; *STDOUT; sub IO::Handle::self { $_[0] };
+(*STDOUT->self . "") =~ m/^GLOB/ and print "ok\n"'
 
 init
 
